import { EditorManager, TextEditor, EditorDecoration, EditorDecorationStyle } from '@wiptheia/editor/lib/browser';
import { GitFileBlame, Commit } from '../../common';
import { Disposable, DisposableCollection } from '@wiptheia/core';
import * as moment from 'moment';
import { HoverProvider, TextDocumentPositionParams, Hover, CancellationToken, Languages } from '@wiptheia/languages/lib/common';
export declare class BlameDecorator implements HoverProvider {
    protected readonly editorManager: EditorManager;
    protected readonly languages: Languages;
    constructor();
    protected registerHoverProvider(uri: string): Disposable;
    protected emptyHover: Hover;
    provideHover(params: TextDocumentPositionParams, token: CancellationToken): Promise<Hover>;
    protected appliedDecorations: Map<string, AppliedBlameDecorations>;
    decorate(blame: GitFileBlame, editor: TextEditor, highlightLine: number): Disposable;
    protected getShaForLine(blame: GitFileBlame, line: number): string | undefined;
    protected toDecorations(blame: GitFileBlame, highlightLine: number): BlameDecorations;
    protected formatContentLine(commit: Commit, commitTime: moment.Moment): string;
    protected now: moment.Moment;
    protected getHeatColor(commitTime: moment.Moment): string;
}
export declare namespace BlameDecorator {
    const maxWidth = 50;
    const defaultGutterStyles: CSSStyleDeclaration;
    const continuationStyle: EditorDecorationStyle;
    const highlightStyle: EditorDecorationStyle;
}
export interface BlameDecorations {
    editorDecorations: EditorDecoration[];
    styles: EditorDecorationStyle[];
}
export declare class AppliedBlameDecorations implements Disposable {
    readonly toDispose: DisposableCollection;
    readonly previousStyles: DisposableCollection;
    readonly previousDecorations: string[];
    blame: GitFileBlame | undefined;
    highlightedSha: string | undefined;
    dispose(): void;
}
