import { h } from "@phosphor/virtualdom";
import URI from "@wiptheia/core/lib/common/uri";
import { StatefulWidget } from "@wiptheia/core/lib/browser";
import { EditorManager, EditorOpenerOptions, EditorWidget, DiffNavigatorProvider } from "@wiptheia/editor/lib/browser";
import { GitFileChange, Git, WorkingDirectoryStatus } from '../../common';
import { GitWatcher } from "../../common";
import { GitNavigableListWidget } from "../git-navigable-list-widget";
import { GitFileChangeNode } from "../git-widget";
export declare const GIT_DIFF = "git-diff";
export declare class GitDiffWidget extends GitNavigableListWidget<GitFileChangeNode> implements StatefulWidget {
    protected fileChangeNodes: GitFileChangeNode[];
    protected options: Git.Options.Diff;
    protected gitStatus: WorkingDirectoryStatus | undefined;
    protected readonly git: Git;
    protected readonly diffNavigatorProvider: DiffNavigatorProvider;
    protected readonly editorManager: EditorManager;
    protected readonly gitWatcher: GitWatcher;
    constructor();
    protected init(): void;
    protected readonly toRevision: string | undefined;
    protected readonly fromRevision: string | number | undefined;
    setContent(options: Git.Options.Diff): Promise<void>;
    storeState(): object;
    restoreState(oldState: any): void;
    protected render(): h.Child;
    protected renderDiffListHeader(): h.Child;
    protected doRenderDiffListHeader(...children: h.Child[]): h.Child;
    protected renderHeaderRow({name, value, classNames}: {
        name: h.Child;
        value: h.Child;
        classNames?: string[];
    }): h.Child;
    protected renderPathHeader(): h.Child;
    protected renderPath(): h.Child;
    protected renderRevisionHeader(): h.Child;
    protected renderRevision(): h.Child;
    protected renderToolbar(): h.Child;
    protected doRenderToolbar(...children: h.Child[]): h.Child;
    protected renderNavigationLeft(): h.Child;
    protected renderNavigationRight(): h.Child;
    protected renderFileChangeList(): h.Child;
    protected renderGitItem(change: GitFileChangeNode): h.Child;
    protected navigateRight(): void;
    protected navigateLeft(): void;
    protected selectNextNode(): void;
    protected selectPreviousNode(): void;
    protected handleListEnter(): void;
    protected openSelected(): void;
    protected getUriToOpen(change: GitFileChange): URI;
    openChanges(uri: URI, options?: EditorOpenerOptions): Promise<EditorWidget | undefined>;
    protected openChange(change: GitFileChange, options?: EditorOpenerOptions): Promise<EditorWidget | undefined>;
    protected revealChange(change: GitFileChange): Promise<void>;
}
