import { ILogger } from '@wiptheia/core/lib/common/logger';
import { Event, Emitter } from '@wiptheia/core/lib/common/event';
import { Tree } from '@wiptheia/core/lib/browser/tree/tree';
import { DisposableCollection } from '@wiptheia/core/lib/common/disposable';
import { PreferenceChangeEvent } from '@wiptheia/core/lib/browser/preferences/preference-proxy';
import { TreeDecorator, TreeDecoration } from '@wiptheia/core/lib/browser/tree/tree-decorator';
import { Git } from '../common/git';
import { GitWatcher } from '../common/git-watcher';
import { WorkingDirectoryStatus } from '../common/git-model';
import { GitRepositoryProvider } from './git-repository-provider';
import { GitFileChange, GitFileStatus } from '../common/git-model';
import { GitPreferences, GitConfiguration } from './git-preferences';
export declare class GitDecorator implements TreeDecorator {
    protected readonly git: Git;
    protected readonly repositoryProvider: GitRepositoryProvider;
    protected readonly watcher: GitWatcher;
    protected readonly preferences: GitPreferences;
    protected readonly logger: ILogger;
    readonly id: string;
    protected readonly toDisposeOnRepositoryChange: DisposableCollection;
    protected readonly emitter: Emitter<(tree: Tree) => Map<string, TreeDecoration.Data>>;
    protected enabled: boolean;
    protected showColors: boolean;
    constructor(git: Git, repositoryProvider: GitRepositoryProvider, watcher: GitWatcher, preferences: GitPreferences, logger: ILogger);
    decorations(tree: Tree): Promise<Map<string, TreeDecoration.Data>>;
    readonly onDidChangeDecorations: Event<(tree: Tree) => Map<string, TreeDecoration.Data>>;
    protected fireDidChangeDecorations(event: (tree: Tree) => Map<string, TreeDecoration.Data>): void;
    protected collectDecorators(tree: Tree, status: WorkingDirectoryStatus): Map<string, TreeDecoration.Data>;
    protected appendContainerChanges(tree: Tree, changes: GitFileChange[]): Map<string, GitFileChange>;
    protected toDecorator(change: GitFileChange): TreeDecoration.Data;
    protected compare(left: GitFileChange, right: GitFileChange): number;
    protected getDecorationColor(status: GitFileStatus, staged?: boolean): string;
    protected handlePreferenceChange(event: PreferenceChangeEvent<GitConfiguration>): Promise<void>;
}
