import { QuickOpenService } from '@wiptheia/core/lib/browser/quick-open/quick-open-service';
import { Git } from '../common';
import { GitRepositoryProvider } from './git-repository-provider';
import { MessageService } from '@wiptheia/core/lib/common/message-service';
/**
 * Service delegating into the `Quick Open Service`, so that the Git commands can be further refined.
 * For instance, the `remote` can be specified for `pull`, `push`, and `fetch`. And the branch can be
 * specified for `git merge`.
 */
export declare class GitQuickOpenService {
    protected readonly git: Git;
    protected readonly repositoryProvider: GitRepositoryProvider;
    protected readonly quickOpenService: QuickOpenService;
    protected readonly messageService: MessageService;
    constructor(git: Git, repositoryProvider: GitRepositoryProvider, quickOpenService: QuickOpenService, messageService: MessageService);
    fetch(): Promise<void>;
    push(): Promise<void>;
    pull(): Promise<void>;
    merge(): Promise<void>;
    checkout(): Promise<void>;
    changeRepository(): Promise<void>;
    chooseTagsAndBranches(execFunc: (branchName: string, currentBranchName: string) => void): Promise<void>;
    commitMessageForAmend(): Promise<string>;
    private open(items, placeholder);
    private getOptions(placeholder, fuzzyMatchLabel?, onClose?);
    private getModel(items);
    private getRepository();
    private getRemotes();
    private getTags();
    private getBranches();
    private getCurrentBranch();
    private logError(error);
}
